@@ -12,7 +12,8 @@ diri.contour <- function(a, n = 100, x = NULL, cont.line = FALSE) {
   x1 <- seq(0.001, 0.999, length = n)  ## coordinates of x
   sqrt3 <- sqrt(3)
   x2 <- seq(0.001, sqrt3/2 - 1e-03, length = n)  ## coordinates of y
-  #suppressWarnings()
+  oop <- options( warn = -1 )
+  on.exit( options(oop) )
   # old code
   # mat <- matrix(nrow = n, ncol = n)
   # be <- prod( gamma(a)) / gamma(sum(a) )  ## beta function
